#!/bin/sh
#// ***************************************************************************
#// *                                                                         *
#// *  Licensed Materials - Property of IBM                                   *
#// *  5724-L62                                                               *
#// *                                                                         *
#// *  (C) Copyright IBM Corp. 2005 All Rights Reserved.                      *
#// *                                                                         *
#// *  US Government Users Restricted Rights - Use, duplication or            *
#// *  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.      *
#// *                                                                         *
#// ***************************************************************************
#//

# /*
# * @author Keyuri Patel
# * Copyright (c) 2004 Cyanea Systems Corp.
# * All rights Reserved.
# */

echo "-------------------------------------------------------------------------------------------------------------------"
echo "    DATABASE SCRIPTS"
echo "-------------------------------------------------------------------------------------------------------------------"

invalidParam ()
{
        key=$1
        val=$2
        echo "Property File $propFile has wrong value:  $key=$val"
        echo "This is not the supported value. Please correct it."
}

checkNullParam()
{
        if [ $# -ne 2 ] ; then
                echo "ERROR: Value for the variable $1 is NULL."
                echo "Please add the value for $1 in a property file $propFile"
                exit
        fi
}


db2 ()
{
	echo "---------------------------------------------------------------------------------------------------------"
	echo "SETTING UP DB2 DATABASE"
	echo "---------------------------------------------------------------------------------------------------------"
	echo "."
        echo "Logs can be found at $AM_HOME/logs directory."
	checkNullParam DB2INST ${DB2INST}
	checkNullParam AM_HOME  ${AM_HOME}
	checkNullParam JDBC_USER ${JDBC_USER}
	checkNullParam db_port ${db_port}

	PATH=$JDBC_DRIVER_CLASSES/../bin:$PATH
	osName=`uname`
	if [ $osName = "Linux" -o $osName = "AIX" ]
	then
		param=" ${DB2INST} ${JDBC_USER} ${AM_HOME} ${db_port}"
	else
		param=" ${DB2INST} ${JDBC_USER} ${AM_HOME}"
	fi
	
	sh ${AM_HOME}/bin/db2install.sh $param
	echo "."
        echo "Database Installation is done."
        echo "---------------------------------------------------------------------------------------------------------"

}

oracle ()
{
	echo "---------------------------------------------------------------------------------------------------------"
	echo "SETTING UP ORACLE DATABASE"
	echo "---------------------------------------------------------------------------------------------------------"
	echo "."
	echo "Logs can be found at $AM_HOME/logs directory."
	
	checkNullParam ORACLE_SQLPLUS_USER ${ORACLE_SQLPLUS_USER} 
	checkNullParam ORACLE_DBA_USER_NAME ${ORACLE_DBA_USER_NAME}
	checkNullParam ORACLE_DBA_PASSWORD  ${ORACLE_DBA_PASSWORD}
	checkNullParam AM_HOME ${AM_HOME}
	checkNullParam ORACLE_TABLESPACE ${ORACLE_TABLESPACE}
	checkNullParam JDBC_USER ${JDBC_USER}
	checkNullParam JDBC_PASSWORD ${JDBC_PASSWORD}
	checkNullParam ORACLE_SID ${ORACLE_SID}	

	#copying am-oracle.sql manually because in chinese locale it gets corrupted when copy using InstallFiles component
	cp ../../mgmt_home/etc/am-oracle.sql $AM_HOME/etc/.
	param="${ORACLE_SQLPLUS_USER}  ${ORACLE_DBA_USER_NAME} ${ORACLE_DBA_PASSWORD} ${AM_HOME} ${ORACLE_TABLESPACE} ${JDBC_USER} ${JDBC_PASSWORD} ${ORACLE_SID} "
	sh ${AM_HOME}/bin/oracleinstall.sh $param
	echo "."
	echo "Database Installation is done."
	echo "---------------------------------------------------------------------------------------------------------"
}

if [ -n "$1" ]  # Test if command line argument present (non-empty).
then
          propFile=$1
else
        echo "Usage: ./Database.sh customValues.properties(FilePath)"
        echo "Please specify the filePath for the property file"
        exit
fi


#load the properties file
propFile=$1
echo "customValues.properties file =" $propFile
. $propFile

#change permission for wsam user with group ownership #13846
USERGROUP=`/usr/bin/id ${JDBC_USER}| sed 's/) groups=.*//' | sed 's/.* gid=.*(//' | sed 's/)//'`
chown ${JDBC_USER}:${USERGROUP} ${AM_HOME}/..
chown -R ${JDBC_USER}:${USERGROUP} ${AM_HOME}

eval `set | ${JAVA_HOME}/bin/java -cp $CYANEA_HOME_OS/lib/common.jar -Dam.home=$CYANEA_HOME_OS com.cyanea.common.util.CheckEnvironment $0 $*`


if [ ${CREATE_DATABASE} = "true" -o   ${CREATE_DATABASE} = "YES" ]
then
	mkdir -p  $AM_HOME/logs
        echo "$AM_HOME/logs created."

	if [ ${DATABASE} = "oracle" -o  ${DATABASE} = "ORACLE" ]
	then
        	oracle
	else
		if [ ${DATABASE} = "db2"  -o  ${DATABASE} = "DB2" ]
        	then
                	db2
        	else
                	invalidParam "DATABASE" ${DATABASE}
        	fi  
	fi
else
	echo "Database is not created"

fi
exit 0

